@@ -1,4 +1,5 @@
 from django.conf import settings
+from django.contrib.sites.models import Site
 from django.core.mail import EmailMultiAlternatives
 from django.template.loader import get_template
 from django_settings_export import settings_export
@@ -16,7 +17,7 @@ def send_email(
     email = EmailMultiAlternatives(
         subject=subject,
         body=template_plaintext.render(template_context),
-        from_email=settings.BUSINESS_EMAIL_VANE,
+        from_email=settings.DEFAULT_FROM_EMAIL,
         to=[email_destination],
     )
     template_html = get_template(template_html_path)
@@ -26,6 +27,8 @@ def send_email(
 
 def _get_full_context(context_base: dict = None) -> dict:
     settings_exported = settings_export(request=None)
+    settings_exported['site'] = Site.objects.get_current()
+    settings_exported['base_url'] = settings.META_SITE_PROTOCOL + Site.objects.get_current().domain
     if context_base is None:
         return settings_exported
     else:
